@@ -3,7 +3,7 @@
 // This file is part of bes, A C++ back-end server implementation framework
 // for the OPeNDAP Data Access Protocol.
 
-// Copyright (c) 2004,2005 University Corporation for Atmospheric Research
+// Copyright (c) 2004-2009 University Corporation for Atmospheric Research
 // Author: Patrick West <pwest@ucar.edu> and Jose Garcia <jgarcia@ucar.edu>
 //
 // This library is free software; you can redistribute it and/or
@@ -52,6 +52,7 @@ using std::ofstream ;
 
 #include "CmdApp.h"
 #include "CmdClient.h"
+#include "CmdTranslation.h"
 #include "BESError.h"
 #include "BESDebug.h"
 
@@ -167,13 +168,13 @@ CmdApp::signalBrokenPipe( int sig )
 	CmdApp *app = dynamic_cast<CmdApp *>(BESApp::TheApplication()) ;
 	if( app )
 	{
-	  CmdClient *client = app->client() ;
-	  if( client )
+	    CmdClient *client = app->client() ;
+	    if( client )
 	    {
-	      client->brokenPipe() ;
-	      client->shutdownClient() ;
-	      delete client;
-	      client = 0;
+		client->brokenPipe() ;
+		client->shutdownClient() ;
+		delete client;
+		client = 0;
 	    }
 	}
 	exit( 1 ) ;
@@ -184,7 +185,7 @@ void
 CmdApp::registerSignals()
 {
     // Registering SIGCONT for connection unblocking
-    BESDEBUG( "cmdln", "CmdApp: Registering signal SIGCONT ... " << endl )
+    BESDEBUG( "cmdln", "CmdApp: Registering signal SIGCONT ... " << endl ) ;
     if( signal( SIGCONT, signalCannotConnect ) == SIG_ERR )
     {
 	BESDEBUG( "cmdln", "FAILED" << endl ) ;
@@ -195,7 +196,7 @@ CmdApp::registerSignals()
 
     // Registering SIGINT to disable Ctrl-C from the user in order to avoid
     // server instability
-    BESDEBUG( "cmdln", "CmdApp: Registering signal SIGINT ... " << endl )
+    BESDEBUG( "cmdln", "CmdApp: Registering signal SIGINT ... " << endl ) ;
     if( signal( SIGINT, signalInterrupt ) == SIG_ERR )
     {
 	BESDEBUG( "cmdln", "FAILED" << endl ) ;
@@ -206,7 +207,7 @@ CmdApp::registerSignals()
 
     // Registering SIGTERM to disable kill from the user in order to avoid
     // server instability
-    BESDEBUG( "cmdln", "CmdApp: Registering signal SIGTERM ... " << endl )
+    BESDEBUG( "cmdln", "CmdApp: Registering signal SIGTERM ... " << endl ) ;
     if( signal( SIGTERM, signalTerminate ) == SIG_ERR )
     {
 	BESDEBUG( "cmdln", "FAILED" << endl ) ;
@@ -216,7 +217,7 @@ CmdApp::registerSignals()
     BESDEBUG( "cmdln", "OK" << endl ) ;
 
     // Registering SIGPIE for broken pipes managment.
-    BESDEBUG( "cmdln", "CmdApp: Registering signal SIGPIPE ... " << endl )
+    BESDEBUG( "cmdln", "CmdApp: Registering signal SIGPIPE ... " << endl ) ;
     if( signal( SIGPIPE, CmdApp::signalBrokenPipe ) == SIG_ERR )
     {
 	BESDEBUG( "cmdln", "FAILED" << endl ) ;
@@ -233,6 +234,8 @@ CmdApp::initialize( int argc, char **argv )
     if( retVal != 0 )
 	return retVal ;
 
+    CmdTranslation::initialize( argc, argv ) ;
+
     string portStr = "" ;
     string outputStr = "" ;
     string inputStr = "" ;
@@ -409,13 +412,13 @@ CmdApp::run()
 	if( _hostStr != "" )
 	{
 	    BESDEBUG( "cmdln", "CmdApp: Connecting to host: " << _hostStr
-	              << " at port: " << _portVal << " ... " << endl )
+	              << " at port: " << _portVal << " ... " << endl ) ;
 	    _client->startClient( _hostStr, _portVal, _timeout ) ;
 	}
 	else
 	{
-	    BESDEBUG( "cmdln", "CmdApp: Connecting to unix socket: " << _unixStr
-	              << " ... " << endl )
+	    BESDEBUG( "cmdln", "CmdApp: Connecting to unix socket: "
+			       << _unixStr << " ... " << endl ) ;
 	    _client->startClient( _unixStr, _timeout ) ;
 	}
 
@@ -443,19 +446,20 @@ CmdApp::run()
 	exit( 1 ) ;
     }
 
+    bool do_exit = false ;
     try
     {
 	if( _cmd != "" )
 	{
-	    _client->executeCommands( _cmd, _repeat ) ;
+	    do_exit = _client->executeCommands( _cmd, _repeat ) ;
 	}
 	else if( _inputStrm )
 	{
-	    _client->executeCommands( *_inputStrm, _repeat ) ;
+	    do_exit = _client->executeCommands( *_inputStrm, _repeat ) ;
 	}
 	else
 	{
-	    _client->interact() ;
+	    do_exit = _client->interact() ;
 	}
     }
     catch( BESError &e )
@@ -469,7 +473,9 @@ CmdApp::run()
 	BESDEBUG( "cmdln", "CmdApp: shutting down client ... " << endl ) ;
 	if( _client )
 	{
-	    _client->shutdownClient() ;
+	    // if do_exit is set, then the client has shut itself down
+	    if( !do_exit )
+		_client->shutdownClient() ;
 	    delete _client ;
 	    _client = 0 ;
 	}
