@@ -3,7 +3,7 @@
 // This file is part of bes, A C++ back-end server implementation framework
 // for the OPeNDAP Data Access Protocol.
 
-// Copyright (c) 2004,2005 University Corporation for Atmospheric Research
+// Copyright (c) 2004-2009 University Corporation for Atmospheric Research
 // Author: Patrick West <pwest@ucar.edu> and Jose Garcia <jgarcia@ucar.edu>
 //
 // This library is free software; you can redistribute it and/or
@@ -48,6 +48,7 @@ using std::endl ;
 #endif
 
 #include "BESStatusResponseHandler.h"
+#include "BESServicesResponseHandler.h"
 #include "BESStreamResponseHandler.h"
 
 #include "BESSetContainerResponseHandler.h"
@@ -67,10 +68,11 @@ using std::endl ;
 #include "BESSetContextResponseHandler.h"
 #include "BESShowContextResponseHandler.h"
 
+#include "BESShowErrorResponseHandler.h"
+
 #include "BESTransmitterNames.h"
 #include "BESReturnManager.h"
 #include "BESBasicTransmitter.h"
-#include "BESBasicHttpTransmitter.h"
 
 #include "BESDebug.h"
 
@@ -83,86 +85,89 @@ using std::endl ;
 int
 BESDefaultModule::initialize(int, char**)
 {
-    BESDEBUG( "bes", "Initializing default modules:" << endl )
+    BESDEBUG( "bes", "Initializing default modules:" << endl ) ;
 
-    BESDEBUG( "bes", "    adding " << HELP_RESPONSE << " response handler" << endl )
+    BESDEBUG( "bes", "    adding " << HELP_RESPONSE << " response handler" << endl ) ;
     BESResponseHandlerList::TheList()->add_handler( HELP_RESPONSE, BESHelpResponseHandler::HelpResponseBuilder ) ;
 
 #ifdef BES_DEVELOPER
-    BESDEBUG( "bes", "    adding " << PROCESS_RESPONSE << " response handler" << endl )
+    BESDEBUG( "bes", "    adding " << PROCESS_RESPONSE << " response handler" << endl ) ;
     BESResponseHandlerList::TheList()->add_handler( PROCESS_RESPONSE, BESProcIdResponseHandler::ProcIdResponseBuilder ) ;
 
-    BESDEBUG( "bes", "    adding " << CONFIG_RESPONSE << " response handler" << endl )
+    BESDEBUG( "bes", "    adding " << CONFIG_RESPONSE << " response handler" << endl ) ;
     BESResponseHandlerList::TheList()->add_handler( CONFIG_RESPONSE, BESConfigResponseHandler::ConfigResponseBuilder ) ;
 #endif
 
-    BESDEBUG( "bes", "    adding " << VERS_RESPONSE << " response handler" << endl )
+    BESDEBUG( "bes", "    adding " << VERS_RESPONSE << " response handler" << endl ) ;
     BESResponseHandlerList::TheList()->add_handler( VERS_RESPONSE, BESVersionResponseHandler::VersionResponseBuilder ) ;
 
-    BESDEBUG( "bes", "    adding " << STATUS_RESPONSE << " response handler" << endl )
+    BESDEBUG( "bes", "    adding " << STATUS_RESPONSE << " response handler" << endl ) ;
     BESResponseHandlerList::TheList()->add_handler( STATUS_RESPONSE, BESStatusResponseHandler::StatusResponseBuilder ) ;
 
-    BESDEBUG( "bes", "    adding " << STREAM_RESPONSE << " response handler" << endl )
+    BESDEBUG( "bes", "    adding " << SERVICE_RESPONSE << " response handler" << endl ) ;
+    BESResponseHandlerList::TheList()->add_handler( SERVICE_RESPONSE, BESServicesResponseHandler::ResponseBuilder ) ;
+
+    BESDEBUG( "bes", "    adding " << STREAM_RESPONSE << " response handler" << endl ) ;
     BESResponseHandlerList::TheList()->add_handler( STREAM_RESPONSE, BESStreamResponseHandler::BESStreamResponseBuilder ) ;
 
-    BESDEBUG( "bes", "    adding " << SETCONTAINER << " response handler" << endl )
+    BESDEBUG( "bes", "    adding " << SETCONTAINER << " response handler" << endl ) ;
     BESResponseHandlerList::TheList()->add_handler( SETCONTAINER, BESSetContainerResponseHandler::SetContainerResponseBuilder ) ;
 
-    BESDEBUG( "bes", "    adding " << SHOWCONTAINERS_RESPONSE << " response handler" << endl )
+    BESDEBUG( "bes", "    adding " << SHOWCONTAINERS_RESPONSE << " response handler" << endl ) ;
     BESResponseHandlerList::TheList()->add_handler( SHOWCONTAINERS_RESPONSE, BESShowContainersResponseHandler::ShowContainersResponseBuilder ) ;
 
-    BESDEBUG( "bes", "    adding " << DELETE_CONTAINER << " response handler" << endl )
+    BESDEBUG( "bes", "    adding " << DELETE_CONTAINER << " response handler" << endl ) ;
     BESResponseHandlerList::TheList()->add_handler( DELETE_CONTAINER, BESDelContainerResponseHandler::DelContainerResponseBuilder ) ;
 
-    BESDEBUG( "bes", "    adding " << DELETE_CONTAINERS << " response handler" << endl)
+    BESDEBUG( "bes", "    adding " << DELETE_CONTAINERS << " response handler" << endl) ;
     BESResponseHandlerList::TheList()->add_handler( DELETE_CONTAINERS, BESDelContainersResponseHandler::DelContainersResponseBuilder ) ;
 
-    BESDEBUG( "bes", "    adding " << PERSISTENCE_VOLATILE << " container persistence" << endl )
+    BESDEBUG( "bes", "    adding " << PERSISTENCE_VOLATILE << " container persistence" << endl ) ;
     BESContainerStorageList::TheList()->add_persistence( new BESContainerStorageVolatile( PERSISTENCE_VOLATILE ) ) ;
 
-    BESDEBUG( "bes", "    adding " << DEFINE_RESPONSE << " response handler" << endl )
+    BESDEBUG( "bes", "    adding " << DEFINE_RESPONSE << " response handler" << endl ) ;
     BESResponseHandlerList::TheList()->add_handler( DEFINE_RESPONSE, BESDefineResponseHandler::DefineResponseBuilder ) ;
 
-    BESDEBUG( "bes", "    adding " << SHOWDEFS_RESPONSE << " response handler" << endl)
+    BESDEBUG( "bes", "    adding " << SHOWDEFS_RESPONSE << " response handler" << endl) ;
     BESResponseHandlerList::TheList()->add_handler( SHOWDEFS_RESPONSE, BESShowDefsResponseHandler::ShowDefsResponseBuilder ) ;
 
-    BESDEBUG( "bes", "    adding " << DELETE_DEFINITION << " response handler" << endl)
+    BESDEBUG( "bes", "    adding " << DELETE_DEFINITION << " response handler" << endl) ;
     BESResponseHandlerList::TheList()->add_handler( DELETE_DEFINITION, BESDelDefResponseHandler::DelDefResponseBuilder ) ;
 
-    BESDEBUG( "bes", "    adding " << DELETE_DEFINITIONS << " response handler" << endl )
+    BESDEBUG( "bes", "    adding " << DELETE_DEFINITIONS << " response handler" << endl ) ;
     BESResponseHandlerList::TheList()->add_handler( DELETE_DEFINITIONS, BESDelDefsResponseHandler::DelDefsResponseBuilder ) ;
 
-    BESDEBUG( "bes", "    adding " << PERSISTENCE_VOLATILE << " definition persistence" << endl )
+    BESDEBUG( "bes", "    adding " << PERSISTENCE_VOLATILE << " definition persistence" << endl ) ;
     BESDefinitionStorageList::TheList()->add_persistence( new BESDefinitionStorageVolatile( PERSISTENCE_VOLATILE ) ) ;
 
-    BESDEBUG( "bes", "    adding " << SET_CONTEXT << " response handler" << endl)
+    BESDEBUG( "bes", "    adding " << SET_CONTEXT << " response handler" << endl) ;
     BESResponseHandlerList::TheList()->add_handler( SET_CONTEXT, BESSetContextResponseHandler::SetContextResponseBuilder ) ;
 
-    BESDEBUG( "bes", "    adding " << SHOW_CONTEXT << " response handler" << endl)
+    BESDEBUG( "bes", "    adding " << SHOW_CONTEXT << " response handler" << endl) ;
     BESResponseHandlerList::TheList()->add_handler( SHOW_CONTEXT, BESShowContextResponseHandler::ShowContextResponseBuilder ) ;
 
-    BESDEBUG( "bes", "    adding " << BASIC_TRANSMITTER << " transmitter" << endl )
+    BESDEBUG( "bes", "    adding " << SHOW_ERROR << " response handler" << endl) ;
+    BESResponseHandlerList::TheList()->add_handler( SHOW_ERROR, BESShowErrorResponseHandler::ResponseBuilder ) ;
+
+    BESDEBUG( "bes", "    adding " << BASIC_TRANSMITTER << " transmitter" << endl ) ;
     BESReturnManager::TheManager()->add_transmitter( BASIC_TRANSMITTER, new BESBasicTransmitter ) ;
 
-    BESDEBUG( "bes", "    adding " << HTTP_TRANSMITTER << " transmitter" << endl )
-    BESReturnManager::TheManager()->add_transmitter( HTTP_TRANSMITTER, new BESBasicHttpTransmitter ) ;
-
-    BESDEBUG( "bes", "    adding " << BES_TEXT_INFO << " info builder" << endl )
+    BESDEBUG( "bes", "    adding " << BES_TEXT_INFO << " info builder" << endl ) ;
     BESInfoList::TheList()->add_info_builder( BES_TEXT_INFO,
 					      BESTextInfo::BuildTextInfo ) ;
 
-    BESDEBUG( "bes", "    adding " << BES_HTML_INFO << " info builder" << endl )
+    BESDEBUG( "bes", "    adding " << BES_HTML_INFO << " info builder" << endl ) ;
     BESInfoList::TheList()->add_info_builder( BES_HTML_INFO,
 					      BESHTMLInfo::BuildHTMLInfo ) ;
 
-    BESDEBUG( "bes", "    adding " << BES_XML_INFO << " info builder" << endl )
+    BESDEBUG( "bes", "    adding " << BES_XML_INFO << " info builder" << endl ) ;
     BESInfoList::TheList()->add_info_builder( BES_XML_INFO,
 					      BESXMLInfo::BuildXMLInfo ) ;
 
-    BESDEBUG( "bes", "    adding bes debug context" << endl )
+    BESDEBUG( "bes", "    adding bes debug context" << endl ) ;
     BESDebug::Register( "bes" ) ;
 
-    BESDEBUG( "bes", "Done Initializing default modules:" << endl )
+    BESDEBUG( "bes", "Done Initializing default modules:" << endl ) ;
 
     return 0 ;
 }
@@ -170,33 +175,33 @@ BESDefaultModule::initialize(int, char**)
 int
 BESDefaultModule::terminate(void)
 {
-    BESDEBUG( "bes", "Removing default modules" << endl )
+    BESDEBUG( "bes", "Removing default modules" << endl ) ;
 
     BESResponseHandlerList::TheList()->remove_handler( HELP_RESPONSE ) ;
     BESResponseHandlerList::TheList()->remove_handler( VERS_RESPONSE ) ;
     BESResponseHandlerList::TheList()->remove_handler( PROCESS_RESPONSE ) ;
     BESResponseHandlerList::TheList()->remove_handler( CONFIG_RESPONSE ) ;
     BESResponseHandlerList::TheList()->remove_handler( STATUS_RESPONSE ) ;
+    BESResponseHandlerList::TheList()->remove_handler( SERVICE_RESPONSE ) ;
 
     BESResponseHandlerList::TheList()->remove_handler( SETCONTAINER ) ;
     BESResponseHandlerList::TheList()->remove_handler( SHOWCONTAINERS_RESPONSE ) ;
     BESResponseHandlerList::TheList()->remove_handler( DELETE_CONTAINER ) ;
     BESResponseHandlerList::TheList()->remove_handler( DELETE_CONTAINERS ) ;
-    BESContainerStorageList::TheList()->del_persistence( PERSISTENCE_VOLATILE ) ;
+    BESContainerStorageList::TheList()->deref_persistence( PERSISTENCE_VOLATILE ) ;
 
     BESResponseHandlerList::TheList()->remove_handler( DEFINE_RESPONSE ) ;
     BESResponseHandlerList::TheList()->remove_handler( SHOWDEFS_RESPONSE ) ;
     BESResponseHandlerList::TheList()->remove_handler( DELETE_DEFINITION ) ;
     BESResponseHandlerList::TheList()->remove_handler( DELETE_DEFINITIONS ) ;
-    BESDefinitionStorageList::TheList()->del_persistence( PERSISTENCE_VOLATILE ) ;
+    BESDefinitionStorageList::TheList()->deref_persistence( PERSISTENCE_VOLATILE ) ;
 
     BESResponseHandlerList::TheList()->remove_handler( SET_CONTEXT ) ;
     BESResponseHandlerList::TheList()->remove_handler( SHOW_CONTEXT ) ;
 
     BESReturnManager::TheManager()->del_transmitter( BASIC_TRANSMITTER ) ;
-    BESReturnManager::TheManager()->del_transmitter( HTTP_TRANSMITTER ) ;
 
-    BESDEBUG( "bes", "Done Removing default modules" << endl )
+    BESDEBUG( "bes", "Done Removing default modules" << endl ) ;
 
     return 0 ;
 }
