@@ -3,7 +3,7 @@
 // This file is part of bes, A C++ back-end server implementation framework
 // for the OPeNDAP Data Access Protocol.
 
-// Copyright (c) 2004,2005 University Corporation for Atmospheric Research
+// Copyright (c) 2004-2009 University Corporation for Atmospheric Research
 // Author:
 //
 // This library is free software; you can redistribute it and/or
@@ -23,7 +23,7 @@
 // You can contact University Corporation for Atmospheric Research at
 // 3080 Center Green Drive, Boulder, CO 80301
  
-// (c) COPYRIGHT University Corporation for Atmostpheric Research 2004-2005
+// (c) COPYRIGHT University Corporation for Atmospheric Research 2004-2005
 // Please read the full copyright statement in the file COPYRIGHT_UCAR.
 //
 // Authors:
@@ -38,6 +38,7 @@
 #include <unistd.h>
 #endif
 
+#include <cstdio>
 #include <cstring>
 #include <cerrno>
 
@@ -111,7 +112,7 @@ BESUncompressZ::uncompress( const string &src, const string &target )
 /*      Start decompress LZW inspired from ncompress-4.2.4.orig         */
 /* ==================================================================== */
 
-    BESDEBUG( "bes", "BESUncompressZ::uncompress - start decompress" << endl);
+    BESDEBUG( "bes", "BESUncompressZ::uncompress - start decompress" << endl) ;
 
 #define	FIRSTBYTE	(unsigned char)'\037'/* First byte of compressed file*/
 #define	SECONDBYTE	(unsigned char)'\235'/* Second byte of compressed file*/
@@ -155,25 +156,26 @@ BESUncompressZ::uncompress( const string &src, const string &target )
 
     insize = 0;
     
-    BESDEBUG( "bes", "BESUncompressZ::uncompress - read file" << endl);	    
+    BESDEBUG( "bes", "BESUncompressZ::uncompress - read file" << endl);	     ;
 /* -------------------------------------------------------------------- */
 /*       Verify if the .Z file start with 0x1f and 0x9d                 */
 /* -------------------------------------------------------------------- */
     while( insize < 3 && (rsize = read(srcFile, inbuf+insize, BUFSIZ)) > 0) {
 	insize += rsize;
     }
-    BESDEBUG( "bes", "BESUncompressZ::uncompress - insize: " << insize << endl); 
+    BESDEBUG( "bes", "BESUncompressZ::uncompress - insize: " << insize << endl);  ;
 
 /* -------------------------------------------------------------------- */
 /*       Do we have compressed file?                                    */
 /* -------------------------------------------------------------------- */
     if( (insize < 3) || (inbuf[0] != FIRSTBYTE) || (inbuf[1] != SECONDBYTE)) {
-	BESDEBUG( "bes", "BESUncompressZ::uncompress - not a compress file" << endl);     
+	BESDEBUG( "bes", "BESUncompressZ::uncompress - not a compress file" << endl);      ;
 	if( rsize < 0) {
 	    string err = "Could not read file ";
 	    err += src.c_str() ;
 	    close( srcFile ) ;
 	    close( destFile ) ;
+	    remove( target.c_str() ) ;
 	    throw BESInternalError( err, __FILE__, __LINE__ ) ;
 	}
 	
@@ -182,12 +184,14 @@ BESUncompressZ::uncompress( const string &src, const string &target )
 	    err += ": not in compressed format";
 	    close( srcFile ) ;
 	    close( destFile ) ;
+	    remove( target.c_str() ) ;
 	    throw BESInternalError( err, __FILE__, __LINE__ ) ;
 	}
 	
 	string err = "unknown error";
 	close( srcFile ) ;
 	close( destFile ) ;
+	remove( target.c_str() ) ;
 	throw BESInternalError( err, __FILE__, __LINE__ ) ;
 
     }
@@ -207,6 +211,7 @@ BESUncompressZ::uncompress( const string &src, const string &target )
 	err += BITS;
 	close( srcFile ) ;
 	close( destFile ) ;
+	remove( target.c_str() ) ;
 	throw BESInternalError( err, __FILE__, __LINE__ ) ;
     }
 
@@ -219,7 +224,7 @@ BESUncompressZ::uncompress( const string &src, const string &target )
 
     free_ent = ((block_mode) ? FIRST : 256);
 
-    BESDEBUG( "bes", "BESUncompressZ::uncompress - entering loop" << endl);
+    BESDEBUG( "bes", "BESUncompressZ::uncompress - entering loop" << endl) ;
    
     memset(codetab, 0, 256);
     
@@ -250,6 +255,7 @@ BESUncompressZ::uncompress( const string &src, const string &target )
 		    err += src.c_str() ;
 		    close( srcFile ) ;
 		    close( destFile ) ;
+		    remove( target.c_str() ) ;
 		    throw BESInternalError( err, __FILE__, __LINE__ ) ;
 		}
 		
@@ -293,6 +299,7 @@ BESUncompressZ::uncompress( const string &src, const string &target )
 			err += " !!!! uncompress: corrupt input!!!";
 			close( srcFile ) ;
 			close( destFile ) ;
+			remove( target.c_str() ) ;
 			throw BESInternalError( err, __FILE__, __LINE__ ) ;
 		    }
 		    outbuf[outpos++] = (unsigned char)(finchar = 
@@ -326,6 +333,7 @@ BESUncompressZ::uncompress( const string &src, const string &target )
 			string err = "uncompress: corrupt input";
 			close( srcFile ) ;
 			close( destFile ) ;
+			remove( target.c_str() ) ;
 			throw BESInternalError( err, __FILE__, __LINE__ ) ;
 		    }
 		    
@@ -361,6 +369,7 @@ BESUncompressZ::uncompress( const string &src, const string &target )
 				    string err = "uncompress: write eror";
 				    close( srcFile ) ;
 				    close( destFile ) ;
+				    remove( target.c_str() ) ;
 				    throw BESInternalError( err, 
 							    __FILE__, 
 							    __LINE__ ) ;
@@ -393,12 +402,13 @@ BESUncompressZ::uncompress( const string &src, const string &target )
 	string err = "uncompress: write eror";
 	close( srcFile ) ;
 	close( destFile ) ;
+	remove( target.c_str() ) ;
 	throw BESInternalError( err, __FILE__, __LINE__ ) ;
     }
 
     close( srcFile ) ;
     close( destFile ) ;
 
-    BESDEBUG( "bes", "BESUncompressZ::uncompress - end decompres" << endl);
+    BESDEBUG( "bes", "BESUncompressZ::uncompress - end decompres" << endl) ;
 }
 
