@@ -3,7 +3,7 @@
 // This file is part of bes, A C++ back-end server implementation framework
 // for the OPeNDAP Data Access Protocol.
 
-// Copyright (c) 2004,2005 University Corporation for Atmospheric Research
+// Copyright (c) 2004-2009 University Corporation for Atmospheric Research
 // Author: Patrick West <pwest@ucar.edu> and Jose Garcia <jgarcia@ucar.edu>
 //
 // This library is free software; you can redistribute it and/or
@@ -34,9 +34,11 @@
 #define E_BESUtil_h 1
 
 #include <string>
+#include <list>
 #include <iostream>
 
 using std::string ;
+using std::list ;
 using std::ostream ;
 
 class BESUtil
@@ -44,6 +46,7 @@ class BESUtil
 private:
     static string		rfc822_date( const time_t t ) ;
 
+    static string		entity( char c ) ;
 public:
     /** These functions are used to create the MIME headers for a message
 	from a server to a client.
@@ -80,6 +83,24 @@ public:
     static char *		fastpidconverter( long val,
 						  char *buf,
 						  int base ) ;
+
+    /** remove leading and trailing blanks from a string **/
+    static void			removeLeadingAndTrailingBlanks( string &key ) ;
+
+    /** convert characters not allowed in xml to escaped characters **/
+    static string		id2xml( string in,
+				        const string &not_allowed = "><&'\"" ) ;
+
+    /** unescape xml escaped characters **/
+    static string		xml2id( string in ) ;
+
+    /** explode a string into an array given a delimiter **/
+    static void			explode( char delim, const string &str,
+					 list<string> &values ) ;
+
+    /** implode a list of values into a single string delimited by delim **/
+    static string		implode( const list<string> &values,
+					 char delim ) ;
 } ;
 
 #endif // E_BESUtil_h
