@@ -55,12 +55,12 @@ using std::ostringstream ;
 #include "BESError.h"
 #include <test_config.h>
 
-class connT: public TestFixture {
+class cacheT: public TestFixture {
 private:
 
 public:
-    connT() {}
-    ~connT() {}
+    cacheT() {}
+    ~cacheT() {}
 
     void setUp()
     {
@@ -99,7 +99,7 @@ public:
 	    system( m.str().c_str() ) ;
 	}
 
-	char *touchers[8] = { "7", "6", "4", "2", "8", "5", "3", "1" } ;
+	string touchers[8] = { "7", "6", "4", "2", "8", "5", "3", "1" } ;
 	for( int i = 0; i < 8; i++ )
 	{
 	    sleep(1);
@@ -146,7 +146,7 @@ public:
 	}
     }
 
-    CPPUNIT_TEST_SUITE( connT ) ;
+    CPPUNIT_TEST_SUITE( cacheT ) ;
 
     CPPUNIT_TEST( do_test ) ;
 
@@ -466,7 +466,7 @@ public:
     }
 } ;
 
-CPPUNIT_TEST_SUITE_REGISTRATION( connT ) ;
+CPPUNIT_TEST_SUITE_REGISTRATION( cacheT ) ;
 
 int 
 main( int, char** )
