@@ -3,7 +3,7 @@
 // This file is part of bes, A C++ back-end server implementation framework
 // for the OPeNDAP Data Access Protocol.
 
-// Copyright (c) 2004,2005 University Corporation for Atmospheric Research
+// Copyright (c) 2004-2009 University Corporation for Atmospheric Research
 // Author: Patrick West <pwest@ucar.edu> and Jose Garcia <jgarcia@ucar.edu>
 //
 // This library is free software; you can redistribute it and/or
@@ -31,7 +31,8 @@
 //      jgarcia     Jose Garcia <jgarcia@ucar.edu>
 
 #include <sys/types.h>
-//#include <sys/uio.h>
+
+#include <cstdio>
 #include <unistd.h> // for sync
 #include <sstream>
 #include <iomanip>
@@ -43,7 +44,7 @@ using std::setw ;
 using std::setfill ;
 
 #include "PPTStreamBuf.h"
-#include "PPTProtocol.h"
+#include "BESDebug.h"
 
 PPTStreamBuf::PPTStreamBuf( int fd, unsigned bufsize )
     : d_bufsize( bufsize ),
@@ -78,7 +79,7 @@ PPTStreamBuf::sync()
     if( pptr() > pbase() )
     {
 	ostringstream strm ;
-	strm << hex << setw( 4 ) << setfill( '0' ) << (unsigned int)(pptr() - pbase()) << "d" ;
+	strm << hex << setw( 7 ) << setfill( '0' ) << (unsigned int)(pptr() - pbase()) << "d" ;
 	string tmp_str = strm.str() ;
 	write( d_fd, tmp_str.c_str(), tmp_str.length() ) ;
 	count += write( d_fd, d_buffer, pptr() - pbase() ) ;
@@ -108,12 +109,13 @@ PPTStreamBuf::finish()
     ostringstream strm ;
     /*
     ostringstream xstrm ;
-    xstrm << "count=" << hex << setw( 8 ) << setfill( '0' ) << how_many() << ";" ;
+    xstrm << "count=" << hex << setw( 7 ) << setfill( '0' ) << how_many() << ";" ;
     string xstr = xstrm.str() ;
-    strm << hex << setw( 4 ) << setfill( '0' ) << (unsigned int)xstr.length() << "x" << xstr ;
+    strm << hex << setw( 7 ) << setfill( '0' ) << (unsigned int)xstr.length() << "x" << xstr ;
     */
-    strm << hex << setw( 4 ) << setfill( '0' ) << (unsigned int)0 << "d" ;
+    strm << hex << setw( 7 ) << setfill( '0' ) << (unsigned int)0 << "d" ;
     string tmp_str = strm.str() ;
+    BESDEBUG( "ppt", "PPTStreamBuf::finish - writing " << tmp_str << endl ) ;
     write( d_fd, tmp_str.c_str(), tmp_str.length() ) ;
     // If something doesn't look right try using fsync
     fsync(d_fd);
