@@ -3,26 +3,26 @@
 // This file is part of bes, A C++ back-end server implementation framework
 // for the OPeNDAP Data Access Protocol.
 
-// Copyright (c) 2004,2005 University Corporation for Atmospheric Research
+// Copyright (c) 2004-2009 University Corporation for Atmospheric Research
 // Author: Patrick West <pwest@ucar.edu> and Jose Garcia <jgarcia@ucar.edu>
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
 // License as published by the Free Software Foundation; either
 // version 2.1 of the License, or (at your option) any later version.
-// 
+//
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 // Lesser General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 //
 // You can contact University Corporation for Atmospheric Research at
 // 3080 Center Green Drive, Boulder, CO 80301
- 
+
 // (c) COPYRIGHT University Corporation for Atmospheric Research 2004-2005
 // Please read the full copyright statement in the file COPYRIGHT_UCAR.
 //
@@ -63,7 +63,7 @@ SSLClient::SSLClient( const string &hostStr, int portVal,
       _kfile( key_file )
 {
 }
-    
+
 SSLClient::~SSLClient()
 {
 }
@@ -71,18 +71,18 @@ SSLClient::~SSLClient()
 void
 SSLClient::initConnection()
 {
-    BESDEBUG( "ppt", "Loading SSL error strings ... " << endl )
+    BESDEBUG( "ppt", "Loading SSL error strings ... " << endl ) ;
     SSL_load_error_strings() ;
-    BESDEBUG( "ppt", "OK" << endl )
+    BESDEBUG( "ppt", "OK" << endl ) ;
 
-    BESDEBUG( "ppt", "Initializing SSL library ... " << endl )
+    BESDEBUG( "ppt", "Initializing SSL library ... " << endl ) ;
     SSL_library_init() ;
-    BESDEBUG( "ppt", "OK" << endl )
+    BESDEBUG( "ppt", "OK" << endl ) ;
 
     SSL_METHOD *method = NULL ;
     SSL_CTX *context = NULL ;
 
-    BESDEBUG( "ppt", "Creating method and context ... " << endl )
+    BESDEBUG( "ppt", "Creating method and context ... " << endl ) ;
     method = SSLv3_client_method() ;
     if( method )
     {
@@ -96,12 +96,12 @@ SSLClient::initConnection()
     }
     else
     {
-	BESDEBUG( "ppt", "OK" << endl )
+	BESDEBUG( "ppt", "OK" << endl ) ;
     }
 
     bool ok_2_continue = false ;
     string err_msg ;
-    BESDEBUG( "ppt", "Setting certificate and key ... " << endl )
+    BESDEBUG( "ppt", "Setting certificate and key ... " << endl ) ;
     if( SSL_CTX_use_certificate_file( context, _cfile.c_str(), SSL_FILETYPE_PEM ) <= 0 )
     {
 	err_msg = "FAILED to use certificate file " + _cfile + "\n" ;
@@ -124,8 +124,8 @@ SSLClient::initConnection()
 
     if( ok_2_continue )
     {
-	BESDEBUG( "ppt", "OK" << endl )
-	BESDEBUG( "ppt", "Certificate setup ... " << endl )
+	BESDEBUG( "ppt", "OK" << endl ) ;
+	BESDEBUG( "ppt", "Certificate setup ... " << endl ) ;
 	SSL_CTX_set_verify( context, SSL_VERIFY_PEER, SSLClient::verify_server ) ;
 	SSL_CTX_set_client_CA_list( context, SSL_load_client_CA_file( _cafile.c_str() ));
 	if( ( !SSL_CTX_load_verify_locations( context, _cafile.c_str(), NULL )) ||
@@ -140,9 +140,10 @@ SSLClient::initConnection()
     int sock_fd = -1 ;
     if( ok_2_continue )
     {
-	BESDEBUG( "ppt", "OK" << endl )
+	BESDEBUG( "ppt", "OK" << endl ) ;
 
-	BESDEBUG( "ppt", "Establishing TCP connection to " << _host << ":" << _port << " ... " << endl )
+	BESDEBUG( "ppt", "Establishing TCP connection to "
+			 << _host << ":" << _port << " ... " << endl ) ;
 	sock_fd = connect_to_server() ;
 	if( sock_fd < 0 )
 	{
@@ -153,9 +154,9 @@ SSLClient::initConnection()
 
     if( ok_2_continue )
     {
-	BESDEBUG( "ppt", "OK" << endl )
+	BESDEBUG( "ppt", "OK" << endl ) ;
 
-	BESDEBUG( "ppt", "Establishing secure connection ... " << endl )
+	BESDEBUG( "ppt", "Establishing secure connection ... " << endl ) ;
 	int ssl_ret = 0 ;
 	_connection = SSL_new( context ) ;
 	if( !_connection )
@@ -186,11 +187,11 @@ SSLClient::initConnection()
 
     if( ok_2_continue )
     {
-	BESDEBUG( "ppt", "OK" << endl )
+	BESDEBUG( "ppt", "OK" << endl ) ;
     }
     else
     {
-	BESDEBUG( "ppt", "FAILED" << endl )
+	BESDEBUG( "ppt", "FAILED" << endl ) ;
 	if( _context ) SSL_CTX_free( _context ) ; _context = NULL ;
 	throw BESInternalError( err_msg, __FILE__, __LINE__ ) ;
     }
@@ -219,6 +220,8 @@ SSLClient::connect_to_server( )
 	struct hostent *hostEntry ;
 	if( ( hostEntry = gethostbyname( _host.c_str() ) ) != 0 )
 	{
+	    if ( hostEntry->h_length > sizeof(addr.sin_addr) )
+	        throw BESInternalError("Memory exception.", __FILE__, __LINE__);
 	    memcpy( &addr.sin_addr, hostEntry->h_addr, hostEntry->h_length ) ;
 	}
 	else
@@ -258,7 +261,7 @@ SSLClient::verify_server( int ok, X509_STORE_CTX *ctx )
 {
     if( ok )
     {
-	BESDEBUG( "ppt", "VERIFIED " << endl )
+	BESDEBUG( "ppt", "VERIFIED " << endl ) ;
     }
     else
     {
@@ -269,28 +272,29 @@ SSLClient::verify_server( int ok, X509_STORE_CTX *ctx )
 	err_cert = X509_STORE_CTX_get_current_cert( ctx ) ;
 	err = X509_STORE_CTX_get_error( ctx ) ;
 	X509_NAME_oneline( X509_get_subject_name( err_cert ), mybuf, 256 ) ;
-	BESDEBUG( "ppt", "FAILED for " << mybuf << endl )
-	BESDEBUG( "ppt", "  " << X509_verify_cert_error_string( err ) << endl )
+	BESDEBUG( "ppt", "FAILED for " << mybuf << endl ) ;
+	BESDEBUG( "ppt", "  " << X509_verify_cert_error_string( err )
+			 << endl ) ;
 	switch( ctx->error )
 	{
 	    case X509_V_ERR_UNABLE_TO_GET_ISSUER_CERT:
 	    {
 		X509_NAME_oneline( X509_get_issuer_name( err_cert ), mybuf, 256 ) ;
-		BESDEBUG( "ppt", "  issuer = " << mybuf << endl )
+		BESDEBUG( "ppt", "  issuer = " << mybuf << endl ) ;
 		break ;
 	    }
 
 	    case X509_V_ERR_CERT_NOT_YET_VALID:
 	    case X509_V_ERR_ERROR_IN_CERT_NOT_BEFORE_FIELD:
 	    {
-		BESDEBUG( "ppt", "  not yet valid!" << endl )
+		BESDEBUG( "ppt", "  not yet valid!" << endl ) ;
 		break ;
 	    }
 
 	    case X509_V_ERR_CERT_HAS_EXPIRED:
 	    case X509_V_ERR_ERROR_IN_CERT_NOT_AFTER_FIELD:
 	    {
-		BESDEBUG( "ppt", "  expired!" << endl )
+		BESDEBUG( "ppt", "  expired!" << endl ) ;
 		break ;
 	    }
 	}
