@@ -3,26 +3,26 @@
 // This file is part of bes, A C++ back-end server implementation framework
 // for the OPeNDAP Data Access Protocol.
 
-// Copyright (c) 2004,2005 University Corporation for Atmospheric Research
+// Copyright (c) 2004-2009 University Corporation for Atmospheric Research
 // Author: Patrick West <pwest@ucar.edu> and Jose Garcia <jgarcia@ucar.edu>
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
 // License as published by the Free Software Foundation; either
 // version 2.1 of the License, or (at your option) any later version.
-// 
+//
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 // Lesser General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 //
 // You can contact University Corporation for Atmospheric Research at
 // 3080 Center Green Drive, Boulder, CO 80301
- 
+
 // (c) COPYRIGHT University Corporation for Atmospheric Research 2004-2005
 // Please read the full copyright statement in the file COPYRIGHT_UCAR.
 //
@@ -51,7 +51,7 @@ using std::flush ;
 #include "BESServerHandler.h"
 #include "Connection.h"
 #include "Socket.h"
-#include "BESCmdInterface.h"
+#include "BESXMLInterface.h"
 #include "TheBESKeys.h"
 #include "BESInternalError.h"
 #include "ServerExitConditions.h"
@@ -64,7 +64,18 @@ using std::flush ;
 BESServerHandler::BESServerHandler()
 {
     bool found = false ;
-    _method = TheBESKeys::TheKeys()->get_key( "BES.ProcessManagerMethod", found ) ;
+    try
+    {
+	TheBESKeys::TheKeys()->get_value( "BES.ProcessManagerMethod",
+					  _method, found ) ;
+    }
+    catch( BESError &e )
+    {
+	cerr << "Unable to determine method to handle clients, "
+	     << "single or multiple as defined by BES.ProcessManagerMethod"
+	     << ": " << e.get_message() << endl ;
+	exit( SERVER_EXIT_FATAL_CAN_NOT_START ) ;
+    }
     if( _method != "multiple" && _method != "single" )
     {
 	cerr << "Unable to determine method to handle clients, "
@@ -103,12 +114,12 @@ BESServerHandler::handle( Connection *c )
 	    // we fork twice so we do not have zombie children
 	    if( ( pid1 = fork() ) < 0 )
 	    {
-		// we must send a signal of inmediate termination to the
-		// main server 
+		// we must send a signal of immediate termination to the
+		// main server
 		kill( main_process, 9 ) ;
 		perror( "fork error" ) ;
 		exit( SERVER_EXIT_CHILD_SUBPROCESS_ABNORMAL_TERMINATION ) ;
-	    } 
+	    }
 	    else if( pid1 == 0 ) /* child of the child */
 	    {
 		execute( c ) ;
@@ -124,7 +135,7 @@ BESServerHandler::handle( Connection *c )
 	    if( error_info )
 		error += " " + (string)error_info ;
 	    throw BESInternalError( error, __FILE__, __LINE__ ) ;
-	} 
+	}
 	c->closeConnection() ;
     }
 }
@@ -153,17 +164,14 @@ BESServerHandler::execute( Connection *c )
 	    exit( CHILD_SUBPROCESS_READY ) ;
 	}
 
-	string cmd_str = BESUtil::www2id( ss.str(), "%", "%20" ) ;
-	BESDEBUG( "server", "BESServerHandler::execute - command = " << cmd_str << endl )
-
-	/*
-	int send_size = 0 ;
-	socklen_t send_size_len = (socklen_t)sizeof( send_size ) ;
-	int ret = getsockopt( c->getSocket()->getSocketDescriptor(),
-			      SOL_SOCKET, SO_SNDBUF,
-			      (char *)&send_size, &send_size_len ) ;
-	cerr << "send_size = " << send_size << endl ;
-	*/
+	// This is code that was in place for the string commands. With xml
+	// documents everything is taken care of by libxml2. This should be
+	// happening in the Interface class before passing to the parser, if
+	// need be. pwest 06 Feb 2009
+	//string cmd_str = BESUtil::www2id( ss.str(), "%", "%20" ) ;
+	string cmd_str = ss.str() ;
+	BESDEBUG( "server", "BESServerHandler::execute - command = "
+			    << cmd_str << endl ) ;
 
 	BESStopWatch *sw = 0 ;
 	if( BESISDEBUG( "timing" ) )
@@ -172,18 +180,21 @@ BESServerHandler::execute( Connection *c )
 	    sw->start() ;
 	}
 
-	unsigned int bufsize = PPT_PROTOCOL_CHUNK_SIZE ;
-	PPTStreamBuf fds( c->getSocket()->getSocketDescriptor(), bufsize ) ;
+	int descript = c->getSocket()->getSocketDescriptor() ;
+
+	unsigned int bufsize = c->getSendChunkSize() ;
+	PPTStreamBuf fds( descript, bufsize ) ;
 	std::streambuf *holder ;
 	holder = cout.rdbuf() ;
 	cout.rdbuf( &fds ) ;
 
-	BESCmdInterface cmd( cmd_str, &cout ) ;
+	BESXMLInterface cmd( cmd_str, &cout ) ;
 	int status = cmd.execute_request( from ) ;
 
 	if( status == 0 )
 	{
-	    BESDEBUG( "server", "BESServerHandler::execute - executed successfully" << endl )
+	    BESDEBUG( "server", "BESServerHandler::execute - "
+				<< "executed successfully" << endl ) ;
 	    fds.finish() ;
 	    cout.rdbuf( holder ) ;
 
@@ -195,26 +206,32 @@ BESServerHandler::execute( Connection *c )
 			      "BESServerHandler::execute - executed in "
 			      << sw->seconds() << " seconds and "
 			      << sw->microseconds() << " microseconds"
-			      << endl )
+			      << endl ) ;
 		}
 		else
 		{
-		    BESDEBUG( "timing", \
-			  "BESServerHandler::execute - no timing available" )
+		    BESDEBUG( "timing", "BESServerHandler::execute - "
+					<< "no timing available" << endl ) ;
 		}
 	    }
 	}
 	else
 	{
 	    // an error has occurred.
-	    BESDEBUG( "server", "BESServerHandler::execute - error occurred" << endl )
+	    BESDEBUG( "server", "BESServerHandler::execute - "
+				<< "error occurred" << endl ) ;
 
 	    // flush what we have in the stream to the client
 	    cout << flush ;
 
-	    // Send the extension status=error to the client so that it can reset.
+	    // Send the extension status=error to the client so that it
+	    // can reset.
 	    map<string,string> extensions ;
 	    extensions["status"] = "error" ;
+	    if( status == BES_INTERNAL_FATAL_ERROR )
+	    {
+		extensions["exit"] = "true" ;
+	    }
 	    c->sendExtensions( extensions ) ;
 
 	    // transmit the error message. finish_with_error will transmit
@@ -234,14 +251,11 @@ BESServerHandler::execute( Connection *c )
 			cout << "BES server " << getpid()
 			     << ": Status not OK, dispatcher returned value "
 			     << status << endl ;
-			//string toSend = "FATAL ERROR: server must exit!" ;
-			//c->send( toSend ) ;
-			c->sendExit() ;
 			c->closeConnection() ;
 			exit( CHILD_SUBPROCESS_READY ) ;
 		    }
 		    break;
-		case BES_INTERNAL_ERROR: 
+		case BES_INTERNAL_ERROR:
 		case BES_SYNTAX_USER_ERROR:
 		case BES_FORBIDDEN_ERROR:
 		case BES_NOT_FOUND_ERROR:
@@ -249,6 +263,8 @@ BESServerHandler::execute( Connection *c )
 		    break;
 	    }
 	}
+
+	if( sw ) delete sw;
     }
 }
 
