@@ -3,26 +3,26 @@
 // This file is part of bes, A C++ back-end server implementation framework
 // for the OPeNDAP Data Access Protocol.
 
-// Copyright (c) 2004,2005 University Corporation for Atmospheric Research
+// Copyright (c) 2004-2009 University Corporation for Atmospheric Research
 // Author: Patrick West <pwest@ucar.edu> and Jose Garcia <jgarcia@ucar.edu>
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
 // License as published by the Free Software Foundation; either
 // version 2.1 of the License, or (at your option) any later version.
-// 
+//
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 // Lesser General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 //
 // You can contact University Corporation for Atmospheric Research at
 // 3080 Center Green Drive, Boulder, CO 80301
- 
+
 // (c) COPYRIGHT University Corporation for Atmospheric Research 2004-2005
 // Please read the full copyright statement in the file COPYRIGHT_UCAR.
 //
@@ -37,12 +37,14 @@
 
 #include <iostream>
 #include <fstream>
+#include <sstream>
 #include <cstdlib>
 
 using std::cout ;
 using std::cerr ;
 using std::endl ;
 using std::ios ;
+using std::ostringstream ;
 using std::ofstream ;
 
 #include "config.h"
@@ -50,6 +52,7 @@ using std::ofstream ;
 #include "ServerApp.h"
 #include "ServerExitConditions.h"
 #include "TheBESKeys.h"
+#include "BESLog.h"
 #include "SocketListener.h"
 #include "TcpSocket.h"
 #include "UnixSocket.h"
@@ -61,7 +64,7 @@ using std::ofstream ;
 #include "BESServerUtils.h"
 
 #include "BESDefaultModule.h"
-#include "BESDefaultCommands.h"
+#include "BESXMLDefaultCommands.h"
 
 ServerApp::ServerApp()
     : BESModuleApp(),
@@ -86,7 +89,7 @@ ServerApp::signalTerminate( int sig )
 {
     if( sig == SIGTERM )
     {
-	BESApp::TheApplication()->terminate( sig ) ;
+        BESApp::TheApplication()->terminate( sig ) ;
 	exit( SERVER_EXIT_NORMAL_SHUTDOWN ) ;
     }
 }
@@ -120,18 +123,31 @@ ServerApp::set_group_id()
     // get group id or name from BES configuration file
     // If BES.Group begins with # then it is a group id,
     // else it is a group name and look up the id.
-    BESDEBUG( "server", "ServerApp: Setting group id ... " << endl )
+    BESDEBUG( "server", "ServerApp: Setting group id ... " << endl ) ;
     bool found = false ;
     string key = "BES.Group" ;
-    string group_str = TheBESKeys::TheKeys()->get_key( key, found ) ;
+    string group_str ;
+    try
+    {
+	TheBESKeys::TheKeys()->get_value( key, group_str, found ) ;
+    }
+    catch( BESError &e )
+    {
+	BESDEBUG( "server", "FAILED" << endl ) ;
+	string err = string("FAILED: ") + e.get_message() ;
+	cerr << err << endl ;
+	(*BESLog::TheLog()) << err << endl ;
+	exit( SERVER_EXIT_FATAL_CAN_NOT_START ) ;
+    }
     if( !found || group_str.empty() )
     {
 	BESDEBUG( "server", "FAILED" << endl ) ;
-	cerr << "FAILED: Group not specified in BES configuration file"
-	     << endl ;
+	string err = "FAILED: Group not specified in BES configuration file" ;
+	cerr << err << endl ;
+	(*BESLog::TheLog()) << err << endl ;
 	exit( SERVER_EXIT_FATAL_CAN_NOT_START ) ;
     }
-    BESDEBUG( "server", "to " << group_str << " ... " << endl )
+    BESDEBUG( "server", "to " << group_str << " ... " << endl ) ;
 
     gid_t new_gid = 0 ;
     if( group_str[0] == '#' )
@@ -149,7 +165,10 @@ ServerApp::set_group_id()
 	if( !ent )
 	{
 	    BESDEBUG( "server", "FAILED" << endl ) ;
-	    cerr << "FAILED: Group " << group_str << " does not exist" << endl ;
+	    string err = (string)"FAILED: Group " + group_str
+			 + " does not exist" ;
+	    cerr << err << endl ;
+	    (*BESLog::TheLog()) << err << endl ;
 	    exit( SERVER_EXIT_FATAL_CAN_NOT_START ) ;
 	}
 	new_gid = ent->gr_gid ;
@@ -158,29 +177,35 @@ ServerApp::set_group_id()
     if( new_gid < 1 )
     {
 	BESDEBUG( "server", "FAILED" << endl ) ;
-	cerr << "FAILED: Group id " << new_gid
-	     << " not a valid group id for BES" << endl ;
+	ostringstream err ;
+	err << "FAILED: Group id " << new_gid
+	    << " not a valid group id for BES" ;
+	cerr << err.str() << endl ;
+	(*BESLog::TheLog()) << err.str() << endl ;
 	exit( SERVER_EXIT_FATAL_CAN_NOT_START ) ;
     }
 
-    BESDEBUG( "server", "to id " << new_gid << " ... " << endl )
+    BESDEBUG( "server", "to id " << new_gid << " ... " << endl ) ;
     if( setgid( new_gid ) == -1 )
     {
 	BESDEBUG( "server", "FAILED" << endl ) ;
-	cerr << "FAILED: unable to set the group id to " << new_gid << endl ;
+	ostringstream err ;
+	err << "FAILED: unable to set the group id to " << new_gid ;
+	cerr << err.str() << endl ;
+	(*BESLog::TheLog()) << err.str() << endl ;
 	exit( SERVER_EXIT_FATAL_CAN_NOT_START ) ;
     }
 
     BESDEBUG( "server", "OK" << endl ) ;
 #else
-    BESDEBUG( "server", "ServerApp: Groups not supported in this OS" << endl )
+    BESDEBUG( "server", "ServerApp: Groups not supported in this OS" << endl ) ;
 #endif
 }
 
 void
 ServerApp::set_user_id()
 {
-    BESDEBUG( "server", "ServerApp: Setting user id ... " << endl )
+    BESDEBUG( "server", "ServerApp: Setting user id ... " << endl ) ;
 
     // Get user name or id from the BES configuration file.
     // If the BES.User value begins with # then it is a user
@@ -188,15 +213,28 @@ ServerApp::set_user_id()
     // user id.
     bool found = false ;
     string key = "BES.User" ;
-    string user_str = TheBESKeys::TheKeys()->get_key( key, found ) ;
+    string user_str ;
+    try
+    {
+	TheBESKeys::TheKeys()->get_value( key, user_str, found ) ;
+    }
+    catch( BESError &e )
+    {
+	BESDEBUG( "server", "FAILED" << endl ) ;
+	string err = (string)"FAILED: " + e.get_message() ;
+	cerr << err << endl ;
+	(*BESLog::TheLog()) << err << endl ;
+	exit( SERVER_EXIT_FATAL_CAN_NOT_START ) ;
+    }
     if( !found || user_str.empty() )
     {
 	BESDEBUG( "server", "FAILED" << endl ) ;
-	cerr << "FAILED: User not specified in BES configuration file"
-	     << endl ;
+	string err = (string)"FAILED: User not specified in BES config file" ;
+	cerr << err << endl ;
+	(*BESLog::TheLog()) << err << endl ;
 	exit( SERVER_EXIT_FATAL_CAN_NOT_START ) ;
     }
-    BESDEBUG( "server", "to " << user_str << " ... " << endl )
+    BESDEBUG( "server", "to " << user_str << " ... " << endl ) ;
 
     uid_t new_id = 0 ;
     if( user_str[0] == '#' )
@@ -212,27 +250,33 @@ ServerApp::set_user_id()
 	if( !ent )
 	{
 	    BESDEBUG( "server", "FAILED" << endl ) ;
-	    cerr << "FAILED: Bad user name specified: "
-		 << user_str << endl ;
+	    string err = (string)"FAILED: Bad user name specified: "
+			 + user_str ;
+	    cerr << err << endl ;
+	    (*BESLog::TheLog()) << err << endl ;
 	    exit( SERVER_EXIT_FATAL_CAN_NOT_START ) ;
 	}
 	new_id = ent->pw_uid ;
     }
 
-    // new user id can not be root (0)
+    // new user id cannot be root (0)
     if( !new_id )
     {
 	BESDEBUG( "server", "FAILED" << endl ) ;
-	cerr << "FAILED: BES can not run as root" << endl ;
+	string err = (string)"FAILED: BES cannot run as root" ;
+	cerr << err << endl ;
+	(*BESLog::TheLog()) << err << endl ;
 	exit( SERVER_EXIT_FATAL_CAN_NOT_START ) ;
     }
 
-    BESDEBUG( "server", "to " << new_id << " ... " << endl )
+    BESDEBUG( "server", "to " << new_id << " ... " << endl ) ;
     if( setuid( new_id ) == -1 )
     {
 	BESDEBUG( "server", "FAILED" << endl ) ;
-	cerr << "FAILED: Unable to set user id to "
-	     << new_id << endl ;
+	ostringstream err ;
+	err << "FAILED: Unable to set user id to " << new_id ;
+	cerr << err.str() << endl ;
+	(*BESLog::TheLog()) << err.str() << endl ;
 	exit( SERVER_EXIT_FATAL_CAN_NOT_START ) ;
     }
 }
@@ -240,18 +284,6 @@ ServerApp::set_user_id()
 int
 ServerApp::initialize( int argc, char **argv )
 {
-    uid_t curr_euid = geteuid() ;
-#ifndef BES_DEVELOPER
-    // must be root to run this app and to set user id and group id later
-    if( curr_euid )
-    {
-	cerr << "FAILED: Must be root to run BES" << endl ;
-	exit( SERVER_EXIT_FATAL_CAN_NOT_START ) ;
-    }
-#else
-    cerr << "Developer Mode: not testing if BES is run by root" << endl ;
-#endif
-
     int c = 0 ;
     bool needhelp = false ;
     string dashi ;
@@ -295,8 +327,13 @@ ServerApp::initialize( int argc, char **argv )
 	}
     }
 
-    // If the -c optiion was passed, set the config file
-    // name in TheBESKeys
+    // before we can do any processing, log any messages, initialize any
+    // modules, do anything, we need to determine where the BES
+    // configuration file lives. From here we get the name of the log
+    // file, group and user id, and information that the modules will
+    // need to run properly.
+
+    // If the -c optiion was passed, set the config file name in TheBESKeys
     if( !dashc.empty() )
     {
 	TheBESKeys::ConfigFile = dashc ;
@@ -315,11 +352,67 @@ ServerApp::initialize( int argc, char **argv )
 	TheBESKeys::ConfigFile = conf_file ;
     }
 
+    // Now that we have the configuration information, we can log to the
+    // BES log file if there are errors in starting up, etc...
+
+    uid_t curr_euid = geteuid() ;
+#ifndef BES_DEVELOPER
+    // must be root to run this app and to set user id and group id later
+    if( curr_euid )
+    {
+	string err = "FAILED: Must be root to run BES" ;
+	cerr << err << endl ;
+	(*BESLog::TheLog()) << err << endl ;
+	exit( SERVER_EXIT_FATAL_CAN_NOT_START ) ;
+    }
+#else
+    cout << "Developer Mode: not testing if BES is run by root" << endl ;
+#endif
+
+    // register the two debug context for the server and ppt. The
+    // Default Module will register the bes context.
+    BESDebug::Register( "server" ) ;
+    BESDebug::Register( "ppt" ) ;
+
+    // Before we can load modules, start writing to the BES log
+    // file, etc... we need to run as the proper user. Set the user
+    // id and the group id to what is specified in the BES
+    // configuration file
+    if( curr_euid == 0 )
+    {
+#ifdef BES_DEVELOPER
+	cout << "Developer Mode: Running as root - setting group and user ids"
+	     << endl ;
+#endif
+	set_group_id() ;
+	set_user_id() ;
+    }
+    else
+    {
+	cout << "Developer Mode: Not setting group or user ids" << endl ;
+    }
+
+    // Because we are now running as the user specified in the
+    // configuraiton file, we won't be able to listen on system ports.
+    // If this is a problem, we may need to move this code above setting
+    // the user and group ids.
     bool found = false ;
     string port_key = "BES.ServerPort" ;
     if( !_gotPort )
     {
-	string sPort = TheBESKeys::TheKeys()->get_key( port_key, found ) ;
+	string sPort ;
+	try
+	{
+	    TheBESKeys::TheKeys()->get_value( port_key, sPort, found ) ;
+	}
+	catch( BESError &e )
+	{
+	    BESDEBUG( "server", "FAILED" << endl ) ;
+	    string err = (string)"FAILED: " + e.get_message() ;
+	    cerr << err << endl ;
+	    (*BESLog::TheLog()) << err << endl ;
+	    exit( SERVER_EXIT_FATAL_CAN_NOT_START ) ;
+	}
 	if( found )
 	{
 	    _portVal = atoi( sPort.c_str() ) ;
@@ -334,19 +427,29 @@ ServerApp::initialize( int argc, char **argv )
     string socket_key = "BES.ServerUnixSocket" ;
     if( _unixSocket == "" )
     {
-	_unixSocket = TheBESKeys::TheKeys()->get_key( socket_key, found ) ;
+	try
+	{
+	    TheBESKeys::TheKeys()->get_value( socket_key, _unixSocket, found ) ;
+	}
+	catch( BESError &e )
+	{
+	    BESDEBUG( "server", "FAILED" << endl ) ;
+	    string err = (string)"FAILED: " + e.get_message() ;
+	    cerr << err << endl ;
+	    (*BESLog::TheLog()) << err << endl ;
+	    exit( SERVER_EXIT_FATAL_CAN_NOT_START ) ;
+	}
     }
 
     if( !_gotPort && _unixSocket == "" )
     {
-	cout << endl << "Must specify either a tcp port"
-	     << " or a unix socket or both" << endl ;
-	cout << "Please specify on the command line with"
-	     << " -p <port> -u <unix_socket> "
-	     << endl
-	     << "Or specify in the bes configuration file with "
-	     << port_key << " and/or " << socket_key
-	     << endl << endl ;
+	string msg = "Must specify a tcp port or a unix socket or both\n" ;
+	msg += "Please specify on the command line with -p <port>" ;
+	msg += " and/or -u <unix_socket>\n" ;
+	msg += "Or specify in the bes configuration file with "
+	    + port_key + " and/or " + socket_key + "\n" ;
+	cout << endl << msg ;
+	(*BESLog::TheLog()) << msg << endl ;
 	BESServerUtils::show_usage( BESApp::TheApplication()->appName() ) ;
     }
 
@@ -354,77 +457,78 @@ ServerApp::initialize( int argc, char **argv )
     if( _secure == false )
     {
 	string key = "BES.ServerSecure" ;
-	string isSecure = TheBESKeys::TheKeys()->get_key( key, found ) ;
+	string isSecure ;
+	try
+	{
+	    TheBESKeys::TheKeys()->get_value( key, isSecure, found ) ;
+	}
+	catch( BESError &e )
+	{
+	    BESDEBUG( "server", "FAILED" << endl ) ;
+	    string err = (string)"FAILED: " + e.get_message() ;
+	    cerr << err << endl ;
+	    (*BESLog::TheLog()) << err << endl ;
+	    exit( SERVER_EXIT_FATAL_CAN_NOT_START ) ;
+	}
 	if( isSecure == "Yes" || isSecure == "YES" || isSecure == "yes" )
 	{
 	    _secure = true ;
 	}
     }
 
-    BESDEBUG( "server", "ServerApp: Registering signal SIGTERM ... " << endl )
+    BESDEBUG( "server", "ServerApp: Registering signal SIGTERM ... " << endl ) ;
     if( signal( SIGTERM, signalTerminate ) == SIG_ERR )
     {
 	BESDEBUG( "server", "FAILED" << endl ) ;
-	cerr << "FAILED: Can not register SIGTERM signal handler" << endl ;
+	string err = "FAILED: cannot register SIGTERM signal handler" ;
+	cerr << err << endl ;
+	(*BESLog::TheLog()) << err << endl ;
 	exit( SERVER_EXIT_FATAL_CAN_NOT_START ) ;
     }
     BESDEBUG( "server", "OK" << endl ) ;
 
-    BESDEBUG( "server", "ServerApp: Registering signal SIGINT ... " << endl )
+    BESDEBUG( "server", "ServerApp: Registering signal SIGINT ... " << endl ) ;
     if( signal( SIGINT, signalInterrupt ) == SIG_ERR )
     {
 	BESDEBUG( "server", "FAILED" << endl ) ;
-	cerr << "FAILED: Can not register SIGINT signal handler" << endl ;
+	string err = "FAILED: cannot register SIGINT signal handler" ;
+	cerr << err << endl ;
+	(*BESLog::TheLog()) << err << endl ;
 	exit( SERVER_EXIT_FATAL_CAN_NOT_START ) ;
     }
     BESDEBUG( "server", "OK" << endl ) ;
 
-    BESDEBUG( "server", "ServerApp: Registering signal SIGUSR1 ... " << endl )
+    BESDEBUG( "server", "ServerApp: Registering signal SIGUSR1 ... " << endl ) ;
     if( signal( SIGUSR1, signalRestart ) == SIG_ERR )
     {
 	BESDEBUG( "server", "FAILED" << endl ) ;
-	cerr << "FAILED: Can not register SIGUSR1 signal handler" << endl ;
+	string err = "FAILED: cannot register SIGUSR1 signal handler" ;
+	cerr << err << endl ;
+	(*BESLog::TheLog()) << err << endl ;
 	exit( SERVER_EXIT_FATAL_CAN_NOT_START ) ;
     }
     BESDEBUG( "server", "OK" << endl ) ;
 
-    BESDEBUG( "server", "ServerApp: initializing default module ... " << endl )
+    BESDEBUG( "server", "ServerApp: initializing default module ... "
+			<< endl ) ;
     BESDefaultModule::initialize( argc, argv ) ;
     BESDEBUG( "server", "OK" << endl ) ;
 
-    BESDEBUG( "server", "ServerApp: initializing default commands ... " << endl )
-    BESDefaultCommands::initialize( argc, argv ) ;
+    BESDEBUG( "server", "ServerApp: initializing default commands ... "
+			<< endl ) ;
+    BESXMLDefaultCommands::initialize( argc, argv ) ;
     BESDEBUG( "server", "OK" << endl ) ;
 
-    BESDebug::Register( "server" ) ;
-    BESDebug::Register( "ppt" ) ;
-
+    // This will load and initialize all of the modules
     int ret = BESModuleApp::initialize( argc, argv ) ;
 
-    BESDEBUG( "server", "ServerApp: initialized settings:" << *this )
+    BESDEBUG( "server", "ServerApp: initialized settings:" << *this ) ;
 
     if( needhelp )
     {
 	BESServerUtils::show_usage( BESApp::TheApplication()->appName() ) ;
     }
 
-    if( curr_euid == 0 )
-    {
-	// Now that we have loaded all modules and given them the chance to
-	// initialize set the user id and the group id to what is specified
-	// in the BES configuration file.
-#ifdef BES_DEVELOPER
-	cerr << "Developer Mode: Running as root - setting group and user ids"
-	     << endl ;
-#endif
-	set_group_id() ;
-	set_user_id() ;
-    }
-    else
-    {
-	cerr << "Developer Mode: Not setting group or user ids" << endl ;
-    }
-
     return ret ;
 }
 
@@ -433,7 +537,8 @@ ServerApp::run()
 {
     try
     {
-	BESDEBUG( "server", "ServerApp: initializing memory pool ... " << endl )
+	BESDEBUG( "server", "ServerApp: initializing memory pool ... "
+			    << endl ) ;
 	BESMemoryManager::initialize_memory_pool() ;
 	BESDEBUG( "server", "OK" << endl ) ;
 
@@ -443,14 +548,16 @@ ServerApp::run()
 	{
 	    _ts = new TcpSocket( _portVal ) ;
 	    listener.listen( _ts ) ;
-	    BESDEBUG( "server", "ServerApp: listening on port (" << _portVal << ")" << endl )
+	    BESDEBUG( "server", "ServerApp: listening on port ("
+				<< _portVal << ")" << endl ) ;
 	}
 
 	if( !_unixSocket.empty() )
 	{
 	    _us = new UnixSocket( _unixSocket ) ;
 	    listener.listen( _us ) ;
-	    BESDEBUG( "server", "ServerApp: listening on unix socket (" << _unixSocket << ")" << endl )
+	    BESDEBUG( "server", "ServerApp: listening on unix socket ("
+				<< _unixSocket << ")" << endl ) ;
 	}
 
 	BESServerHandler handler ;
@@ -461,11 +568,14 @@ ServerApp::run()
     catch( BESError &se )
     {
 	cerr << se.get_message() << endl ;
+	(*BESLog::TheLog()) << se.get_message() << endl ;
 	return 1 ;
     }
     catch( ... )
     {
 	cerr << "caught unknown exception" << endl ;
+	(*BESLog::TheLog()) << "caught unknown exception initializing sockets"
+			    << endl ;
 	return 1 ;
     }
 
@@ -494,12 +604,14 @@ ServerApp::terminate( int sig )
 	    delete _us ;
 	}
 
-	BESDEBUG( "server", "ServerApp: terminating default module ... " << endl )
+	BESDEBUG( "server", "ServerApp: terminating default module ... "
+			    << endl ) ;
 	BESDefaultModule::terminate( ) ;
 	BESDEBUG( "server", "OK" << endl ) ;
 
-	BESDEBUG( "server", "ServerApp: terminating default commands ... " << endl )
-	BESDefaultCommands::terminate( ) ;
+	BESDEBUG( "server", "ServerApp: terminating default commands ...  "
+			    << endl ) ;
+	BESXMLDefaultCommands::terminate( ) ;
 	BESDEBUG( "server", "OK" << endl ) ;
 
 	BESModuleApp::terminate( sig ) ;
