@@ -3,7 +3,7 @@
 // This file is part of bes, A C++ back-end server implementation framework
 // for the OPeNDAP Data Access Protocol.
 
-// Copyright (c) 2004,2005 University Corporation for Atmospheric Research
+// Copyright (c) 2004-2009 University Corporation for Atmospheric Research
 // Author: Patrick West <pwest@ucar.edu> and Jose Garcia <jgarcia@ucar.edu>
 //
 // This library is free software; you can redistribute it and/or
@@ -49,8 +49,9 @@ using std::ofstream ;
 #include "BESError.h"
 #include "BESDebug.h"
 #include "BESDefaultModule.h"
-#include "BESDefaultCommands.h"
+#include "BESXMLDefaultCommands.h"
 #include "TheBESKeys.h"
+#include "CmdTranslation.h"
 
 StandAloneApp::StandAloneApp()
     : BESModuleApp(),
@@ -96,6 +97,8 @@ StandAloneApp::showUsage( )
 int
 StandAloneApp::initialize( int argc, char **argv )
 {
+    CmdTranslation::initialize( argc, argv ) ;
+
     string outputStr = "" ;
     string inputStr = "" ;
     string repeatStr = "" ;
@@ -208,12 +211,14 @@ StandAloneApp::initialize( int argc, char **argv )
 
     try
     {
-	BESDEBUG( "standalone", "ServerApp: initializing default module ... " << endl )
+	BESDEBUG( "standalone", "ServerApp: initializing default module ... "
+				<< endl ) ;
 	BESDefaultModule::initialize( argc, argv ) ;
 	BESDEBUG( "standalone", "OK" << endl ) ;
 
-	BESDEBUG( "standalone", "ServerApp: initializing default commands ... " << endl )
-	BESDefaultCommands::initialize( argc, argv ) ;
+	BESDEBUG( "standalone", "ServerApp: initializing default commands ... "
+				<< endl ) ;
+	BESXMLDefaultCommands::initialize( argc, argv ) ;
 	BESDEBUG( "standalone", "OK" << endl ) ;
 
 	int retval = BESModuleApp::initialize( argc, argv ) ;
@@ -227,7 +232,8 @@ StandAloneApp::initialize( int argc, char **argv )
 	return 1 ;
     }
 
-    BESDEBUG( "standalone", "StandAloneApp: initialized settings:" << endl << *this ) ;
+    BESDEBUG( "standalone", "StandAloneApp: initialized settings:"
+			    << endl << *this ) ;
 
     return 0 ;
 }
@@ -246,7 +252,7 @@ StandAloneApp::run()
 	{
 	    _client->setOutput( &cout, false ) ;
 	}
-	BESDEBUG( "cmdln", "OK" << endl ) ;
+	BESDEBUG( "standalone", "OK" << endl ) ;
     }
     catch( BESError &e )
     {
@@ -255,7 +261,7 @@ StandAloneApp::run()
 	    delete _client ;
 	    _client = 0 ;
 	}
-	BESDEBUG( "cmdln", "FAILED" << endl ) ;
+	BESDEBUG( "standalone", "FAILED" << endl ) ;
 	cerr << "error starting the client" << endl ;
 	cerr << e.get_message() << endl ;
 	exit( 1 ) ;
@@ -284,26 +290,28 @@ StandAloneApp::run()
 
     try
     {
-	BESDEBUG( "cmdln", "StandAloneApp: shutting down client ... " << endl )
+	BESDEBUG( "standalone", "StandAloneApp: shutting down client ... "
+				<< endl ) ;
 	if( _client )
 	{
 	    delete _client ;
 	    _client = 0 ;
 	}
-	BESDEBUG( "cmdln", "OK" << endl ) ;
+	BESDEBUG( "standalone", "OK" << endl ) ;
 
-	BESDEBUG( "cmdln", "StandAloneApp: closing input stream ... " << endl )
+	BESDEBUG( "standalone", "StandAloneApp: closing input stream ... "
+				<< endl ) ;
 	if( _createdInputStrm )
 	{
 	    _inputStrm->close() ;
 	    delete _inputStrm ;
 	    _inputStrm = 0 ;
 	}
-	BESDEBUG( "cmdln", "OK" << endl )
+	BESDEBUG( "standalone", "OK" << endl ) ;
     }
     catch( BESError &e )
     {
-	BESDEBUG( "cmdln", "FAILED" << endl )
+	BESDEBUG( "standalone", "FAILED" << endl ) ;
 	cerr << "error closing the client" << endl ;
 	cerr << e.get_message() << endl ;
 	return 1 ;
@@ -320,16 +328,20 @@ StandAloneApp::run()
 int
 StandAloneApp::terminate( int sig )
 {
-    BESDEBUG( "server", "ServerApp: terminating default module ... " << endl )
+    BESDEBUG( "standalone", "ServerApp: terminating default module ... "
+			    << endl ) ;
     BESDefaultModule::terminate( ) ;
-    BESDEBUG( "server", "OK" << endl ) ;
+    BESDEBUG( "standalone", "OK" << endl ) ;
 
-    BESDEBUG( "server", "ServerApp: terminating default commands ... " << endl )
-    BESDefaultCommands::terminate( ) ;
-    BESDEBUG( "server", "OK" << endl ) ;
+    BESDEBUG( "standalone", "ServerApp: terminating default commands ...  "
+			    << endl ) ;
+    BESXMLDefaultCommands::terminate( ) ;
+    BESDEBUG( "standalone", "OK" << endl ) ;
 
     BESModuleApp::terminate( sig ) ;
 
+    CmdTranslation::terminate( ) ;
+
     return sig ;
 }
 
